SystemOrganization addCategory: #ConfigurationOfXPath!

Object subclass: #ConfigurationOfXPath
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfXPath'!

!ConfigurationOfXPath commentStamp: 'monty 4/22/2017 16:04' prior: 0!
Loads the XPath library and related packages:
	(ConfigurationOfXPath project version: #stable) load: #('default')

The loadable groups are:
	default - XPath, XMLParser, and XMLWriter with tests.
	Core - XPath and XMLParser without XMLWriter  or tests.
	CoreWithWriting - XPath, XMLParser, and XMLWriter without tests.!

!ConfigurationOfXPath class methodsFor: 'development support' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfXPath class methodsFor: 'private' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'StephanEggermont 3/17/2015 15:19'!
catalogChangeLog
    		
     ^ '- Development moved to Baseline 1.0.6, for ci build on pharo-contribution ci.
- Version 1.0 migrated to Pharo 3.0'

! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'monty 2/12/2015 01:02'!
catalogDescription

	^ 'An XPath library for Pharo, Squeak, and Gemstone leveraging the XML parsing capabilities of XMLParser. Supports XPath 1.0 syntax with extensions.'! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'monty 4/12/2015 02:29'!
catalogKeyClassesAndExample

	^ ' ==XPath==, ==XPathContext==, and ==XPathNodeSet== are the main public classes of the package.

The following example retrieves the language types as found in the UNICODE Common Locale Data Repository (CDLR) 
[[[ 
| doc |
doc := (XMLDOMParser parseURL: ''http://unicode.org/repos/cldr/trunk/common/supplemental/supplementalData.xml'').

"get all language type attribute nodes"
(XPath for: ''//languageData/language/@type'') in: doc.

"abbreviated form"
doc // ''languageData'' / ''language'' @ ''type''
]]]'! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'monty 4/7/2015 09:38'!
catalogKeywords

	^ #(XPath XML DOM HTML XHTML parser web markup document query )
					! !

!ConfigurationOfXPath class methodsFor: 'catalog' stamp: 'monty 1/8/2016 13:21'!
catalogLicense
	^ 'The MIT License (MIT)

Copyright (c) 2016 PharoExtras Team.

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.'! !

!ConfigurationOfXPath class methodsFor: 'private' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfXPath class methodsFor: 'private' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfXPath class methodsFor: 'metacello tool support' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfXPath class methodsFor: 'loading' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfXPath class methodsFor: 'loading' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfXPath class methodsFor: 'loading' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfXPath class methodsFor: 'accessing' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
project

	^self new project! !

!ConfigurationOfXPath class methodsFor: 'development support' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 5/28/2015 03:20'!
baseline101: spec
	<version: '1.0.1-baseline' imports: #('1.0-baseline')>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.2' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 5/28/2015 03:20'!
baseline105: spec
	<version: '1.0.5-baseline' imports: #('1.0-baseline')>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.3' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 5/28/2015 03:20'!
baseline106: spec
	<version: '1.0.6-baseline' imports: #('1.0-baseline')>
	spec for: #common do: [ spec blessing: #baseline ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.4' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 6/5/2017 16:44'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://www.smalltalkhub.com/mc/PharoExtras/XPath/main'.
		spec
			project: 'XMLParser'
			with: [ 
				spec
					className: 'ConfigurationOfXMLParser';
					versionString: #stable;
					loads: #('Core');
					repository: 'http://smalltalkhub.com/mc/PharoExtras/XMLParser/main' ].
		spec
			project: 'XMLParserCoreWithWriting'
			copyFrom: 'XMLParser'
			with: [ spec loads: #('CoreWithWriting') ].
		spec
			project: 'XMLParserTests'
			copyFrom: 'XMLParser'
			with: [ spec loads: #('Tests') ].
		spec package: 'XPath-Core' with: [ spec requires: 'XMLParser' ].
		spec package: 'XPath-Tests' with: [ spec requires: #('XMLParserTests' 'XPath-Core') ].

		spec group: 'default' with: #('CoreWithWriting' 'Tests').
		spec group: 'Core' with: #('XPath-Core').
		spec group: 'CoreWithWriting' with: #('XMLParserCoreWithWriting' 'XPath-Core').
		spec group: 'Tests' with: #('XPath-Tests')].

	spec for: #squeakCommon do: [
		spec
			package: 'XPath-Core'
			with: [ spec includes: 'XPath-SqueakCommonCompatibility' ].
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: [ spec requires: 'XPath-Core' ]. ].

	spec for: #gemstone do: [
		spec
			package: 'XPath-Core'
			with: [ spec includes: 'XPath-GemstoneCompatibility' ].
		spec
			package: 'XPath-GemstoneCompatibility'
			with: [ spec requires: 'XPath-Core' ]. ].

	spec
		for: #gt
		do: [
			"the extensions require XMLWriter"
			spec
				group: 'CoreWithWriting' with: #('XMLParserCoreWithWriting' 'XPath-Core' 'XPath-GTExtensions');
				group: 'Tests' with: #('XPath-Tests' 'XPath-GTExtensions').
			spec
				package: 'XPath-GTExtensions'
				with: [ spec requires: 'XPath-Core' ]. ].! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 7/15/2015 15:45'!
baseline134: spec
	<version: '1.3.4-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.4' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.5' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 10/8/2015 06:18'!
baseline149: spec
	<version: '1.4.9-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.5' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.6' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 10/11/2015 05:19'!
baseline151: spec
	<version: '1.5.1-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.5' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.7' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 10/30/2015 20:48'!
baseline155: spec
	<version: '1.5.5-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.5' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.8' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/14/2016 05:02'!
baseline158: spec
	<version: '1.5.8-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.6' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.9' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/18/2016 06:34'!
baseline160: spec
	<version: '1.6.0-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.6.3' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.10' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/23/2016 13:22'!
baseline162: spec
	<version: '1.6.2-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.6.3' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 3/2/2016 19:30'!
baseline163: spec
	<version: '1.6.3-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.6.5' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 3/14/2016 01:41'!
baseline165: spec
	<version: '1.6.5-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.6.8' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 3/26/2016 01:34'!
baseline166: spec
	<version: '1.6.6-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.7.3' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 4/2/2016 02:47'!
baseline167: spec
	<version: '1.6.7-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.7.4' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 4/21/2016 08:26'!
baseline168: spec
	<version: '1.6.8-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.7.6' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 7/17/2016 04:48'!
baseline169: spec
	<version: '1.6.9-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.8.1' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 8/16/2016 23:29'!
baseline170: spec
	<version: '1.7.0-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.8.3' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 9/8/2016 12:14'!
baseline171: spec
	<version: '1.7.1-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.8.7' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 9/22/2016 18:41'!
baseline172: spec
	<version: '1.7.2-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.8.9' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 9/28/2016 23:33'!
baseline173: spec
	<version: '1.7.3-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 10/30/2016 10:39'!
baseline174: spec
	<version: '1.7.4-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.5' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 11/28/2016 02:34'!
baseline176: spec
	<version: '1.7.6-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.7' ].
	spec for: #gemstone do: [ spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11' ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 12/3/2016 01:39'!
baseline177: spec
	<version: '1.7.7-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.8' ].
	spec for: #gemstone do: [
		spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.11'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline177. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 1/24/2017 22:16'!
baseline180: spec
	<version: '1.8.0-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.8' ].
	spec for: #gemstone do: [
		spec package: 'XPath-GemstoneCompatibility' with: 'XPath-GemstoneCompatibility-monty.12'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline180. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 1/27/2017 12:02'!
baseline182: spec
	<version: '1.8.2-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.8' ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.13'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline180. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 1/27/2017 22:48'!
baseline183: spec
	<version: '1.8.3-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.8' ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.13'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline183. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/10/2017 23:30'!
baseline189: spec
	<version: '1.8.9-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.8'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.14'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/14/2017 02:20'!
baseline190: spec
	<version: '1.9.0-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.8'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.15'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/20/2017 04:06'!
baseline191: spec
	<version: '1.9.1-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-2.9.8'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 2/26/2017 09:00'!
baseline192: spec
	<version: '1.9.2-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 3/8/2017 15:38'!
baseline194: spec
	<version: '1.9.4-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.12'. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 3/28/2017 05:36'!
baseline198: spec
	<version: '1.9.8-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.18'. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 4/2/2017 00:45'!
baseline200: spec
	<version: '2.0.0-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.20'. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 4/4/2017 22:18'!
baseline201: spec
	<version: '2.0.1-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.21'. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 5/20/2017 03:40'!
baseline202: spec
	<version: '2.0.2-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.1.7'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.26'. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 8/31/2017 07:46'!
baseline205: spec
	<version: '2.0.5-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.1.9'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline189. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.27'. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 10/17/2017 02:00'!
baseline206: spec
	<version: '2.0.6-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.2.2'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline206. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.27'. ]! !

!ConfigurationOfXPath methodsFor: 'baselines' stamp: 'monty 1/23/2018 08:11'!
baseline209: spec
	<version: '2.0.9-baseline' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec project: 'XMLParser' with: #'release-3.2.9'.
			spec postLoadDoIt: #clearXPathCache. ].
	spec for: #squeakCommon do: [
		spec
			package: 'XPath-SqueakCommonCompatibility'
			with: 'XPath-SqueakCommonCompatibility-monty.1'. ].
	spec for: #gemstone do: [
		spec
			package: 'XPath-GemstoneCompatibility'
			with: 'XPath-GemstoneCompatibility-monty.16'.

		"force initialization of lazy-initialized class and class isnt
		vars to avoid write conflicts on GS"
		spec postLoadDoIt: #initializeClassesForGSBaseline206. ].
	spec for: #gt do: [
		spec
			package: 'XPath-GTExtensions'
			with: 'XPath-GTExtensions-monty.27'. ]! !

!ConfigurationOfXPath methodsFor: 'doits' stamp: 'monty 2/10/2017 20:04'!
clearXPathCache
	XPath clearCompiledExpressionCache! !

!ConfigurationOfXPath methodsFor: 'accessing' stamp: 'monty 3/1/2017 18:19'!
customProjectAttributes
	"Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes "

	(Smalltalk includesKey: #GTInspector)
		ifTrue: [ ^ #(gt) ]
		ifFalse: [ ^ #() ]! !

!ConfigurationOfXPath methodsFor: 'symbolic versions' stamp: 'monty 1/23/2018 08:11'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '2.0.9-baseline'.! !

!ConfigurationOfXPath methodsFor: 'doits' stamp: 'monty 10/8/2017 21:13'!
initializeClassesForGSBaseline177
	"All lazily initialized class and class instance variables must be
	explicitly initialized on GS during installation to prevent write
	conflicts between Gems later on. 
	
	This can help identify classes that use lazy initialization:
		ConfigurationOfXMLParser findLazyInitializedClassStateInPackage: 'XPath'
	"

	XPath compiledXPathCache.
	"renamed"
	(XMLClassFinder classNamed: #XPathCompiler) systemCompilerClass.
	XPathFunction allSubclassesDo: [:each |
		each functionPrototype].
	XPathContext defaultFunctions.
	"renamed"
	(XMLClassFinder classNamed: #XPathNodeTestParserContext) allSubclassesDo: [:each |
		each instance].
	XPathSortOrder allSubclassesDo: [:each |
		each instance].! !

!ConfigurationOfXPath methodsFor: 'doits' stamp: 'monty 10/8/2017 21:13'!
initializeClassesForGSBaseline180
	"All lazily initialized class and class instance variables must be
	explicitly initialized on GS during installation to prevent write
	conflicts between Gems later on. 
	
	This can help identify classes that use lazy initialization:
		ConfigurationOfXMLParser findLazyInitializedClassStateInPackage: 'XPath'
	"

	XPath compiledXPathCache.
	"renamed"
	(XMLClassFinder classNamed: #XPathCompiler) systemCompilerClass.
	XPathFunction allSubclassesDo: [:each |
		each prototype].
	XPathContext defaultFunctions.
	"renamed"
	(XMLClassFinder classNamed: #XPathNodeTestParserContext) allSubclassesDo: [:each |
		each instance].
	XPathSortOrder allSubclassesDo: [:each |
		each instance].
	XPathASTNullNode instance.! !

!ConfigurationOfXPath methodsFor: 'doits' stamp: 'monty 10/8/2017 21:14'!
initializeClassesForGSBaseline183
	"All lazily initialized class and class instance variables must be
	explicitly initialized on GS during installation to prevent write
	conflicts between Gems later on. 
	
	This can help identify classes that use lazy initialization:
		ConfigurationOfXMLParser findLazyInitializedClassStateInPackage: 'XPath'
	"

	XPath compiledXPathCache.
	"renamed"
	(XMLClassFinder classNamed: #XPathCompiler) systemCompilerClass.
	XPathFunction allSubclassesDo: [:each |
		each prototype].
	XPathContext defaultFunctions.
	"renamed"
	(XMLClassFinder classNamed: #XPathNodeTestParserContext) allSubclassesDo: [:each |
		each instance].
	XPathSortOrder allSubclassesDo: [:each |
		each instance].
	XPathASTNullNode instance.
	XPathType allSubclassesDo: [:each |
		each instance].! !

!ConfigurationOfXPath methodsFor: 'doits' stamp: 'monty 10/8/2017 21:14'!
initializeClassesForGSBaseline189
	"All lazily initialized class and class instance variables must be
	explicitly initialized on GS during installation to prevent write
	conflicts between Gems later on. 
	
	This can help identify classes that use lazy initialization:
		ConfigurationOfXMLParser findLazyInitializedClassStateInPackage: 'XPath'
	"

	XPath
		compiledExpressionCache;
		compiledExpressionCacheEnabled.
	XPathASTNullNode instance.
	XPathContext defaultFunctions.
	XPathExpressionCompiler systemCompilerClass.
	XPathFunction allSubclassesDo: [:each |
		each prototype].
	"renamed"
	(XMLClassFinder classNamed: #XPathNodeTestParserContext) allSubclassesDo: [:each |
		each instance].
	XPathSortOrder allSubclassesDo: [:each |
		each instance].
	XPathType allSubclassesDo: [:each |
		each instance].! !

!ConfigurationOfXPath methodsFor: 'doits' stamp: 'monty 10/8/2017 21:15'!
initializeClassesForGSBaseline206
	"All lazily initialized class and class instance variables must be
	explicitly initialized on GS during installation to prevent write
	conflicts between Gems later on. 
	
	This can help identify classes that use lazy initialization:
		ConfigurationOfXMLParser findLazyInitializedClassStateInPackage: 'XPath'
	"

	XPath
		compiledExpressionCache;
		compiledExpressionCacheEnabled.
	XPathASTNullNode instance.
	XPathContext defaultFunctions.
	XPathExpressionCompiler systemCompilerClass.
	XPathFunction allSubclassesDo: [:each |
		each prototype].
	XPathNodeTestParserState allSubclassesDo: [:each |
		each instance].
	XPathSortOrder allSubclassesDo: [:each |
		each instance].
	XPathType allSubclassesDo: [:each |
		each instance].! !

!ConfigurationOfXPath methodsFor: 'accessing' stamp: 'HernanMoralesDurand 9/6/2013 21:14'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfXPath methodsFor: 'symbolic versions' stamp: 'monty 1/23/2018 08:11'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '2.0.9'.
! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/11/2015 01:20'!
version101: spec 
        <version: '1.0.1' imports: #('1.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.8'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.4'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/12/2015 01:02'!
version102: spec 
        <version: '1.0.2' imports: #('1.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.9'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.5'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/13/2015 01:08'!
version103: spec 
        <version: '1.0.3' imports: #('1.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.10'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.5'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/13/2015 22:30'!
version104: spec 
        <version: '1.0.4' imports: #('1.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.11'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.6'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/2/2015 17:49'!
version105: spec 
        <version: '1.0.5' imports: #('1.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.12'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.7'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/3/2015 18:01'!
version106: spec 
        <version: '1.0.6' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.13'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.8'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/5/2015 08:20'!
version107: spec 
        <version: '1.0.7' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.14'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.9'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/10/2015 09:09'!
version108: spec 
        <version: '1.0.8' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.15'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.10'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/10/2015 15:12'!
version109: spec 
        <version: '1.0.9' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.16'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.11'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'HernanMoralesDurand 1/31/2014 12:31'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: ''.
		spec author: 'HernanMoralesDurand'.

		spec timestamp: '31/1/2014 21:15'.
		spec package: 'XPath' with: 'XPath-HernanMoralesDurand.12'. ].
! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/11/2015 12:22'!
version110: spec 
        <version: '1.1.0' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.17'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.12'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/12/2015 19:24'!
version111: spec 
        <version: '1.1.1' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.18'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.13'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/12/2015 20:43'!
version112: spec 
        <version: '1.1.2' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.19'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.14'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/13/2015 22:33'!
version113: spec 
        <version: '1.1.3' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.20'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.15'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/15/2015 22:07'!
version114: spec 
        <version: '1.1.4' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.21'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.16'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/17/2015 18:46'!
version115: spec 
        <version: '1.1.5' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.22'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.17'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/19/2015 21:49'!
version116: spec 
        <version: '1.1.6' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.23'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.18'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/21/2015 17:35'!
version117: spec 
        <version: '1.1.7' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.24'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.19'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/22/2015 02:57'!
version118: spec 
        <version: '1.1.8' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.25'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.19'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/25/2015 04:15'!
version119: spec 
        <version: '1.1.9' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.26'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.20'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/25/2015 20:38'!
version120: spec 
        <version: '1.2.0' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.27'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.21'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/26/2015 00:02'!
version121: spec 
        <version: '1.2.1' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.28'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.22'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/27/2015 00:15'!
version122: spec 
        <version: '1.2.2' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.29'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.23'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/27/2015 20:35'!
version123: spec 
        <version: '1.2.3' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.30'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.24'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/27/2015 21:52'!
version124: spec 
        <version: '1.2.4' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.31'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.25'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/31/2015 21:18'!
version125: spec 
        <version: '1.2.5' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.32'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.26'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/1/2015 00:12'!
version126: spec 
        <version: '1.2.6' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.33'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.27'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/1/2015 09:21'!
version127: spec 
        <version: '1.2.7' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.34'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.27'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/1/2015 20:25'!
version128: spec 
        <version: '1.2.8' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.35'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.28'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/2/2015 00:03'!
version129: spec 
        <version: '1.2.9' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.36'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.29'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/2/2015 08:27'!
version130: spec 
        <version: '1.3.0' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.37'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.30'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/2/2015 09:05'!
version131: spec 
        <version: '1.3.1' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.38'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.31'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/4/2015 07:35'!
version132: spec 
        <version: '1.3.2' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.39'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.32'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/6/2015 09:38'!
version133: spec 
        <version: '1.3.3' imports: #('1.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.40'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.32'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/7/2015 20:35'!
version134: spec 
        <version: '1.3.4' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.41'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.33'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/12/2015 01:28'!
version135: spec 
        <version: '1.3.5' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.42'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.34'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/13/2015 06:10'!
version136: spec 
        <version: '1.3.6' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.43'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.35'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/15/2015 08:07'!
version137: spec 
        <version: '1.3.7' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.44'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.36'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/16/2015 15:03'!
version138: spec 
        <version: '1.3.8' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.45'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.37'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/20/2015 07:14'!
version139: spec 
        <version: '1.3.9' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.46'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.38'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 5/29/2015 06:47'!
version140: spec 
        <version: '1.4.0' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.48'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.38'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 6/3/2015 03:23'!
version141: spec 
        <version: '1.4.1' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.49'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.40'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 6/5/2015 04:10'!
version142: spec 
        <version: '1.4.2' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.50'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.41'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 6/8/2015 00:00'!
version143: spec 
        <version: '1.4.3' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.51'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.42'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 6/11/2015 03:33'!
version144: spec 
        <version: '1.4.4' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.52'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.43'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 6/19/2015 01:04'!
version145: spec 
        <version: '1.4.5' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.54'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.45'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 6/30/2015 09:23'!
version146: spec 
        <version: '1.4.6' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.55'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.46'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 7/5/2015 09:43'!
version147: spec 
        <version: '1.4.7' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.56'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.47'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 8/16/2015 23:30'!
version148: spec 
        <version: '1.4.8' imports: #('1.3.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.57'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.48'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/8/2015 06:18'!
version149: spec 
        <version: '1.4.9' imports: #('1.4.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.58'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.49'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/10/2015 04:29'!
version150: spec 
        <version: '1.5.0' imports: #('1.4.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.59'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.50'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/11/2015 05:19'!
version151: spec 
        <version: '1.5.1' imports: #('1.5.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.60'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.51'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/16/2015 03:40'!
version152: spec 
        <version: '1.5.2' imports: #('1.5.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.61'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.52'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/17/2015 04:25'!
version153: spec 
        <version: '1.5.3' imports: #('1.5.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.62'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.53'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/18/2015 12:00'!
version154: spec 
        <version: '1.5.4' imports: #('1.5.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.63'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.54'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 11/1/2015 09:39'!
version155: spec 
        <version: '1.5.5' imports: #('1.5.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.65'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.56'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 11/19/2015 00:32'!
version156: spec 
        <version: '1.5.6' imports: #('1.5.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.66'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.57'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 11/19/2015 22:57'!
version157: spec 
        <version: '1.5.7' imports: #('1.5.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.67'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.58'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 11/21/2015 00:44'!
version158: spec 
        <version: '1.5.8' imports: #('1.5.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.68'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.59'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/29/2016 15:34'!
version159: spec 
        <version: '1.5.9' imports: #('1.5.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.68'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.60'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/18/2016 06:33'!
version160: spec 
        <version: '1.6.0' imports: #('1.6.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.70'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.60'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/22/2016 08:55'!
version161: spec 
        <version: '1.6.1' imports: #('1.6.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.71'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.60'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/23/2016 13:21'!
version162: spec 
        <version: '1.6.2' imports: #('1.6.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.72'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.60'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/2/2016 19:30'!
version163: spec 
        <version: '1.6.3' imports: #('1.6.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.73'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.61'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/6/2016 21:21'!
version164: spec 
        <version: '1.6.4' imports: #('1.6.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.74'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.62'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/14/2016 01:40'!
version165: spec 
        <version: '1.6.5' imports: #('1.6.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.75'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.62'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/26/2016 01:33'!
version166: spec 
        <version: '1.6.6' imports: #('1.6.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.76'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.63'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/2/2016 02:47'!
version167: spec 
        <version: '1.6.7' imports: #('1.6.7-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.77'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.64'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/21/2016 08:26'!
version168: spec 
        <version: '1.6.8' imports: #('1.6.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.78'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.65'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 7/6/2016 02:08'!
version169: spec 
        <version: '1.6.9' imports: #('1.6.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.79'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.66'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 8/16/2016 23:29'!
version170: spec 
        <version: '1.7.0' imports: #('1.7.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.79'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.67'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 9/6/2016 02:30'!
version171: spec 
        <version: '1.7.1' imports: #('1.7.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.80'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.68'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 9/22/2016 18:42'!
version172: spec 
        <version: '1.7.2' imports: #('1.7.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.81'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.69'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 9/28/2016 23:33'!
version173: spec 
        <version: '1.7.3' imports: #('1.7.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.82'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.69'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/9/2016 18:23'!
version174: spec 
        <version: '1.7.4' imports: #('1.7.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.83'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.69'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 11/9/2016 13:00'!
version175: spec 
        <version: '1.7.5' imports: #('1.7.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.84'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.70'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 11/28/2016 02:33'!
version176: spec 
        <version: '1.7.6' imports: #('1.7.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.85'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.71'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 12/3/2016 01:40'!
version177: spec 
        <version: '1.7.7' imports: #('1.7.7-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.86'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.72'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 12/6/2016 09:46'!
version178: spec 
        <version: '1.7.8' imports: #('1.7.7-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.87'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.72'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 12/31/2016 00:30'!
version179: spec 
        <version: '1.7.9' imports: #('1.7.7-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.88'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.73'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/25/2017 15:26'!
version180: spec 
        <version: '1.8.0' imports: #('1.8.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.91'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.75'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/26/2017 12:18'!
version181: spec 
        <version: '1.8.1' imports: #('1.8.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.92'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.76'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/27/2017 13:04'!
version182: spec 
        <version: '1.8.2' imports: #('1.8.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.94'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.77'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/27/2017 22:51'!
version183: spec 
        <version: '1.8.3' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.95'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.78'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/29/2017 15:05'!
version184: spec 
        <version: '1.8.4' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.96'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.79'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/30/2017 03:46'!
version185: spec 
        <version: '1.8.5' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.97'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.80'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/30/2017 22:14'!
version186: spec 
        <version: '1.8.6' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.98'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.81'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/31/2017 23:43'!
version187: spec 
        <version: '1.8.7' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.99'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.82'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/2/2017 19:19'!
version188: spec 
        <version: '1.8.8' imports: #('1.8.3-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.100'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.83'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/10/2017 23:47'!
version189: spec 
        <version: '1.8.9' imports: #('1.8.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.102'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.84'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/14/2017 02:19'!
version190: spec 
        <version: '1.9.0' imports: #('1.9.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.103'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.86'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/20/2017 04:42'!
version191: spec 
        <version: '1.9.1' imports: #('1.9.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.104'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.88'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 2/26/2017 09:00'!
version192: spec 
        <version: '1.9.2' imports: #('1.9.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.105'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.89'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/1/2017 07:29'!
version193: spec 
        <version: '1.9.3' imports: #('1.9.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.107'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.90'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/1/2017 18:52'!
version194: spec 
        <version: '1.9.4' imports: #('1.9.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.109'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.90'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/4/2017 13:02'!
version195: spec 
        <version: '1.9.5' imports: #('1.9.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.110'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.90'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/8/2017 21:10'!
version196: spec 
        <version: '1.9.6' imports: #('1.9.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.111'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.91'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/9/2017 21:36'!
version197: spec 
        <version: '1.9.7' imports: #('1.9.4-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.112'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.91'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/25/2017 03:13'!
version198: spec 
        <version: '1.9.8' imports: #('1.9.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.113'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.92'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 3/27/2017 02:15'!
version199: spec 
        <version: '1.9.9' imports: #('1.9.8-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.114'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.92'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/2/2017 00:45'!
version200: spec 
        <version: '2.0.0' imports: #('2.0.0-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.116'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.92'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/4/2017 22:19'!
version201: spec 
        <version: '2.0.1' imports: #('2.0.1-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.117'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.92'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/13/2017 06:23'!
version202: spec 
        <version: '2.0.2' imports: #('2.0.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.118'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.92'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 4/22/2017 16:08'!
version203: spec 
        <version: '2.0.3' imports: #('2.0.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.119'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.93'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 5/21/2017 18:58'!
version204: spec 
        <version: '2.0.4' imports: #('2.0.2-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.120'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.94'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 8/31/2017 07:45'!
version205: spec 
        <version: '2.0.5' imports: #('2.0.5-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.121'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.95'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/8/2017 21:15'!
version206: spec 
        <version: '2.0.6' imports: #('2.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.122'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.95'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/25/2017 11:28'!
version207: spec 
        <version: '2.0.7' imports: #('2.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.123'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.95'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 10/26/2017 07:56'!
version208: spec 
        <version: '2.0.8' imports: #('2.0.6-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.124'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.95'.
                ].! !

!ConfigurationOfXPath methodsFor: 'versions' stamp: 'monty 1/23/2018 08:11'!
version209: spec 
        <version: '2.0.9' imports: #('2.0.9-baseline')>

        spec for: #common do: [
                spec blessing: #release.
			spec package: 'XPath-Core' with: 'XPath-Core-monty.125'.
			spec package: 'XPath-Tests' with: 'XPath-Tests-monty.96'.
                ].! !
